summaryrefslogtreecommitdiff
path: root/docs/shared_bindings_matrix.py
diff options
context:
space:
mode:
authorScott Shawcroft <scott@tannewt.org>2020-04-27 16:45:10 -0700
committerScott Shawcroft <scott@tannewt.org>2020-04-27 16:45:10 -0700
commit755d404edf00ab99bb8497d2e4a36ba18dd17a69 (patch)
treea705a06789c0d9b182633ff669380e241b1acc59 /docs/shared_bindings_matrix.py
parentf13de32208716387ca822fd25625325162b5c2f1 (diff)
parentfaa50df05fa11c3903934419a2ad7d7063cf23c7 (diff)
Merge remote-tracking branch 'adafruit/master' into lower_power
Diffstat (limited to 'docs/shared_bindings_matrix.py')
-rw-r--r--docs/shared_bindings_matrix.py19
1 files changed, 8 insertions, 11 deletions
diff --git a/docs/shared_bindings_matrix.py b/docs/shared_bindings_matrix.py
index e327d6ec6..d5f838f75 100644
--- a/docs/shared_bindings_matrix.py
+++ b/docs/shared_bindings_matrix.py
@@ -26,7 +26,7 @@ import os
import re
-SUPPORTED_PORTS = ["atmel-samd", "nrf", "mimxrt10xx"]
+SUPPORTED_PORTS = ["atmel-samd", "nrf", "stm", "mimxrt10xx"]
def parse_port_config(contents, chip_keyword=None):
@@ -139,7 +139,10 @@ def get_excluded_boards(base):
re_board_chip = re.compile("CHIP_FAMILY\s=\s(\w+)")
chip_keyword = "CHIP_FAMILY"
elif port in ["nrf"]:
- re_board_chip = re.compile("MCU_VARIANT\s=\s(\w+)")
+ re_board_chip = re.compile(r"MCU_VARIANT\s=\s(\w+)")
+ elif port in ["stm"]:
+ re_board_chip = re.compile(r"MCU_SERIES\s*=\s*(\w+)")
+ chip_keyword = "MCU_SERIES"
port_dir = "ports/{}".format(port)
@@ -158,10 +161,10 @@ def get_excluded_boards(base):
contents = board.read()
board_chip = re_board_chip.search(contents)
- #print(entry.name, board_chip.group(1))
if not board_chip:
board_chip = "Unknown Chip"
else:
+ #print(entry.name, board_chip.group(1))
board_chip = board_chip.group(1)
# add port_config results to contents
@@ -172,18 +175,12 @@ def get_excluded_boards(base):
check_dependent_modules = dict()
for module in modules:
board_is_excluded = False
# check if board uses `SMALL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded
- small_build = re.search("CIRCUITPY_SMALL_BUILD = 1", contents)
+ small_build = re.search("CIRCUITPY_FULL_BUILD = 0", contents)
if small_build and base[module]["full_build"] == "1":
board_is_excluded = True
- # check if board uses `MINIMAL_BUILD`. if yes, and current
- # module is marked as `DEFAULT_BUILD`, board is excluded
- min_build = re.search("CIRCUITPY_MINIMAL_BUILD = 1", contents)
- if min_build and base[module]["default_value"] == "CIRCUITPY_DEFAULT_BUILD":
- board_is_excluded = True
-
# check if module is specifically disabled for this board
re_pattern = r"CIRCUITPY_{}\s=\s(\w)".format(module.upper())
find_module = re.search(re_pattern, contents)
@@ -172,18 +175,12 @@ def get_excluded_boards(base):
for module in modules:
board_is_excluded = False
- # check if board uses `SMALL_BUILD`. if yes, and current
+ # check if board turns off `FULL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded